@@ -1,7 +1,8 @@
 # TOOL bedtools-pairtopair.R: "Compare two BEDPE files" (Compares two BEDPE files in search of overlaps where each end of a BEDPE feature in A overlaps with the ends of a feature in B. This tool is based on the BEDTools package.)
 # INPUT file.a: "BEDPE file A" TYPE GENERIC
 # INPUT file.b: "BEDPE file B" TYPE GENERIC
-# OUTPUT pairtopair.bed 
+# OUTPUT OPTIONAL pairtopair.bed 
+# OUTPUT OPTIONAL error.txt
 # PARAMETER OPTIONAL f: "Minimum overlap" TYPE DECIMAL FROM 0 TO 1 DEFAULT 0.000000001 (Minimum overlap required as a fraction of A. Default is 1E-9 (effectively 1bp\))
 # PARAMETER OPTIONAL type: "Approach to reporting overlaps" TYPE [either, neither, both] DEFAULT both (either: Report overlaps if either ends of A overlap B. neither: Report A if neither end of A overlaps B. both: Report overlaps if both ends of A overlap B.)
 # PARAMETER OPTIONAL is: "Ignore strands when searching for overlaps" TYPE [yes, no] DEFAULT no (Ignore strands when searching for overlaps. By default, strands are enforced.)
@@ -11,6 +12,7 @@
 # PARAMETER OPTIONAL ss: "Add slop based to each BEDPE footprint based on strand" TYPE [yes, no] DEFAULT no (Add slop based to each BEDPE footprint based on strand. If strand is +, slop is only added to the end coordinates. If strand is -, slop is only added to the start coordinates. By default, slop is added in both directions.) 
 
 # AMS 23.4.2012
+# AMS 23.9.2013 Improved output/error file handling
 
 # binary
 binary <- c(file.path(chipster.tools.path, "bedtools", "bin", "pairToPair"))
@@ -29,8 +31,17 @@ if (addslop == "yes"){
 options <- paste(options,"-a file.a -b file.b")
 
 # command
-command <- paste(binary, options, " > pairtopair.bed")
+command <- paste(binary, options, " > pairtopair.tmp 2> error.tmp")
 
 # run
 system(command)
-if (file.info("pairtopair.bed")$size == 0) {system("echo \"No results found\" > pairtopair.bed")}
+
+# Generate output/error message
+if (file.info("pairtopair.tmp")$size > 0) {
+	system("mv pairtopair.tmp pairtopair.bed")
+} else if (file.info("error.tmp")$size > 0) {
+	system("mv error.tmp error.txt")
+} else{
+	system("echo \"# No results found\" > error.txt")
+}
+
