@@ -4,27 +4,11 @@ import java.io.File;
 
 import fi.csc.microarray.analyser.java.JavaAnalysisJobBase;
 import fi.csc.microarray.client.visualisation.methods.gbrowser.runtimeIndex.BedLineParser;
-import fi.csc.microarray.client.visualisation.methods.gbrowser.util.ChromosomeNormaliser;
 import fi.csc.microarray.client.visualisation.methods.gbrowser.util.TsvSorter;
 import fi.csc.microarray.messaging.JobState;
+import fi.csc.microarray.util.Exceptions;
 
 public class SortBed extends JavaAnalysisJobBase {
-
-	public static final ChromosomeNormaliser CHROMOSOME_NORMALISER = new ChromosomeNormaliser() {
-
-		public String normaliseChromosome(String chromosomeName) {
-
-			// Leave prefix as it is
-			
-			// Remove postfix, if present
-			String SEPARATOR = ".";
-			if (chromosomeName.contains(SEPARATOR)) {
-				chromosomeName = chromosomeName.substring(0, chromosomeName.indexOf(SEPARATOR));
-			}
-			
-			return chromosomeName;
-		}
-	};
 	
 	@Override
 	public String getSADL() {
@@ -48,11 +32,12 @@ public class SortBed extends JavaAnalysisJobBase {
 			// run sort
 			//BEDParser increments coordinates by one, but it's not a problem because only its column order is used
 			new TsvSorter().sort(
-					inputFile, outputFile, CHROMOSOME_NORMALISER,
-					BedLineParser.Column.CHROMOSOME.ordinal(), BedLineParser.Column.START.ordinal(), new BedLineParser(false));
+					inputFile, outputFile,
+					BedLineParser.Column.CHROM.ordinal(), BedLineParser.Column.CHROM_START.ordinal(), new BedLineParser(false));
 
 		} catch (Exception e) {
-			updateState(JobState.FAILED, e.getMessage());
+			getResultMessage().setErrorMessage(Exceptions.getStackTrace(e));
+			updateState(JobState.FAILED, "");
 			return;
 		}
 
